﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;

using Android.App;
using Android.Content;
using Android.Graphics;
using Android.OS;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using Com.Syncfusion.Charts;

namespace Chart_GettingStarted
{
    [Activity(Label = "Sample", MainLauncher = true)]
    public class Sample : Activity
    {
        ViewModel1 viewModel;
        SfChart chartArea;
        protected override void OnCreate(Bundle savedInstanceState)
        {
            base.OnCreate(savedInstanceState);

            chartArea = new SfChart(this);
            chartArea.SetBackgroundColor(Color.White);

            viewModel = new ViewModel1();

            //Initializing primary axis
            CategoryAxis primaryAxisArea = new CategoryAxis();
            primaryAxisArea.Title.Text = "Pizza #";
            chartArea.PrimaryAxis = primaryAxisArea;
            chartArea.PrimaryAxis.AutoScrollingDelta = 4; //на графике 4 максимум
            chartArea.PrimaryAxis.AutoScrollingMode = ChartAutoScrollingMode.Start; //стартуем с начала при пролистыавании

            //Initializing secondary Axis
            NumericalAxis secondaryAxisArea = new NumericalAxis();
            secondaryAxisArea.Title.Text = "Area (in m²)";
            chartArea.SecondaryAxis = secondaryAxisArea;

            chartArea.AnnotationClicked += ChartArea_AnnotationClicked;
            chartArea.TooltipCreated += ChartArea_TooltipCreated;

             //Initializing column series
             ColumnSeries seriesArea = new ColumnSeries();
            seriesArea.ItemsSource = viewModel.compares;
            seriesArea.XBindingPath = "Name";
            seriesArea.YBindingPath = "Area";
            seriesArea.ColorModel.ColorPalette = ChartColorPalette.Metro;//цвет
            seriesArea.DataMarker.LabelStyle.LabelFormat = "#.#### m²";//формат чисел
            seriesArea.DataMarkerLabelCreated += SeriesArea_DataMarkerLabelCreated;
            
            seriesArea.DataPointSelectionEnabled = true;//выбрать столбик

            //ивент выбора столбика, когда столбюик выбран считаем по методу расчеты в % и показываем их, когда столбик не выбран показываем стадартные рассчеты
            int idxArea = 0;

            chartArea.SelectionChanged += Chart_SelectionChanged;
            
            void Chart_SelectionChanged(object sender, SfChart.SelectionChangedEventArgs e)
            {
                
                if (e.P1.SelectedDataPointIndex > -1)
                {
                    int index = seriesArea.SelectedDataPointIndex;
                    
                    while (idxArea < viewModel.compares.Count())
                    {
                        if (viewModel.compares[index].Area != 0)
                        {
                            viewModel.compares[idxArea].InPercent = Math.Round((viewModel.compares[idxArea].Area / viewModel.compares[index].Area) * 100 - 100, 2);
                            if (viewModel.compares[idxArea].InPercent == 0 && e.P1.SelectedDataPointIndex == idxArea)
                            {
                                VerticalLineAnnotation lineAnnotation1 = new VerticalLineAnnotation() { StrokeWidth = 10, StrokeColor = Color.Transparent };
                                lineAnnotation1.X1 = idxArea;
                                lineAnnotation1.Y1 = 0;
                                lineAnnotation1.Text = "0 % ";
                                lineAnnotation1.LabelStyle.TextSize = 20;
                                lineAnnotation1.LabelStyle.VerticalLabelAlignment = ChartAnnotationAlignment.End;
                                lineAnnotation1.LabelStyle.HorizontalLabelAlignment = ChartAnnotationAlignment.Center;
                                chartArea.Annotations.Clear();
                                chartArea.Annotations.Add(lineAnnotation1);
                            }
                        }
                        idxArea++;
                    }
                    seriesArea.YBindingPath = "InPercent";
                    seriesArea.DataMarker.LabelStyle.LabelFormat = "#.##'%'";//формат чисел
                    //Toast.MakeText(Application.Context, Convert.ToString(index), ToastLength.Short).Show();
                }
                else
                {
                    idxArea = 0;
                    chartArea.Annotations.Clear();
                    seriesArea.YBindingPath = "Area";
                    seriesArea.DataMarker.LabelStyle.LabelFormat = "#.#### m²";//формат чисел
                }
            }
            
            //seriesArea.SelectedDataPointColor = Color.Red; //цвет выбранного столбика

            seriesArea.DataMarker.ShowLabel = true;
            seriesArea.Label = "Area";
            seriesArea.TooltipEnabled = true;


            ChartZoomPanBehavior zoomArea = new ChartZoomPanBehavior();// скрол в сторону
            zoomArea.DoubleTapEnabled = false;
            zoomArea.ZoomingEnabled = false;
            zoomArea.ScrollingEnabled = true;
            chartArea.Behaviors.Add(zoomArea);

            
            chartArea.Series.Add(seriesArea);
            chartArea.Legend.Visibility = Visibility.Visible;
            //FindViewById<LinearLayout>(Resource.Id.LayoutChartArea).AddView(chartArea);
            SetContentView(chartArea);

            // Create your application here
        }

        private void ChartArea_TooltipCreated(object sender, SfChart.TooltipCreatedEventArgs e)
        {
            var ser = e.P1.Series;
            var data = e.P1.Series.ItemsSource as ObservableCollection<Model>;
            if(ser.SelectedDataPointIndex > 0)
                e.P1.Label =  data[ser.SelectedDataPointIndex].Area.ToString();
        }
        
       
        private void SeriesArea_DataMarkerLabelCreated(object sender, ChartSeries.DataMarkerLabelCreatedEventArgs e)
        {
            e.DataMarkerLabel.Label = e.DataMarkerLabel.Label;
            var data = e.DataMarkerLabel.Data as Model;
            if (data != null && (chartArea.Series[0] as ColumnSeries).YBindingPath == "InPercent" && data.InPercent == 0)
            {
                e.DataMarkerLabel.BackgroundColor = Color.Transparent;
                e.DataMarkerLabel.Label = string.Empty;
            }
        }

        private void ChartArea_AnnotationClicked(object sender, ChartAnnotationClickedEventArgs e)
        {
             //add your code here   
        }
    }
    public class ViewModel1
    {
        public ObservableCollection<Model> compares { get; set; }
        public ObservableCollection<Model> Data1 { get; set; }

        public ViewModel1()
        {
            compares = new ObservableCollection<Model>()
            {
                new Model(){Name = "Pizza", Area = 19, InPercent = 20},
                new Model(){Name = "Pizza", Area = 12, InPercent = 30},
                new Model(){Name = "Pizza", Area = 0, InPercent = 24},
                new Model(){Name = "Pizza", Area = 10, InPercent = 20},
                new Model(){Name = "Pizza", Area = 15, InPercent = 15},
                new Model(){Name = "Pizza", Area = 25, InPercent = 18},
                new Model(){Name = "Pizza", Area = 35, InPercent = 22},
                new Model(){Name = "Pizza", Area = 28, InPercent = 32},
                new Model(){Name = "Pizza", Area = 23, InPercent = 23},
            };

            Data1 = new ObservableCollection<Model>()
            {
                new Model(){Name = "Pizza", Area = 15},
                new Model(){Name = "Pizza", Area = 12},
                new Model(){Name = "Pizza", Area = 14},
                new Model(){Name = "Pizza", Area = 13},
            };
        }
    }
    public class Model
    {
        public string Name { get; set; }
        public double Area { get; set; }
        public double InPercent { get; set; }
    }
}